Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1053)

Unified Diff: content/public/common/context_menu_params.h

Issue 23200006: Don't show the search-by-image menu item when the image is blocked (no image pixel data) (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: Created 7 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/common/view_messages.h ('k') | content/public/common/context_menu_params.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/public/common/context_menu_params.h
===================================================================
--- content/public/common/context_menu_params.h (revision 218524)
+++ content/public/common/context_menu_params.h (working copy)
@@ -5,6 +5,7 @@
#ifndef CONTENT_PUBLIC_COMMON_CONTEXT_MENU_PARAMS_H_
#define CONTENT_PUBLIC_COMMON_CONTEXT_MENU_PARAMS_H_
+#include <string>
#include <vector>
#include "base/basictypes.h"
@@ -72,8 +73,9 @@
// video.
GURL src_url;
- // This is true if the context menu was invoked on a blocked image.
- bool is_image_blocked;
+ // This is true if the context menu was invoked on an image which has
+ // non-empty contents.
+ bool has_image_contents;
// This is the URL of the top level page that the context menu was invoked
// on.
@@ -154,7 +156,6 @@
gfx::Point selection_start;
gfx::Point selection_end;
#endif
-
};
} // namespace content
« no previous file with comments | « content/common/view_messages.h ('k') | content/public/common/context_menu_params.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698